package com.xyxsbj.mylibrary.tool;

import android.app.Application;
import android.content.Context;
import android.content.SharedPreferences;
import android.text.TextUtils;
import android.util.Base64;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Map;

/**
 * 创建人 mQ
 * 创建时间 2019/5/20 0020 10:32
 * 文件名称 SPTool
 * 说明: SharedPreferences工具类
 * 用来存储轻量数据
 **/
public class SPTool {

    private static Application context;
    /**
     * 保存在手机里面的文件名
     */
    private static String FILE_NAME;

    //初始化方式
    public static void init(Application application, String fileName) {
        context = application;
        FILE_NAME = fileName;
    }

    /**
     * 保存字符串数据
     *
     * @param key
     * @param str 要存的内容
     */
    public static void saveString(String key, String str) {
        SharedPreferences sp = context.getSharedPreferences(FILE_NAME, Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = sp.edit();
        editor.putString(key, str);
        editor.commit();
    }

    /**
     * 保存字符串数据
     *
     * @param key
     * @param str 要存的内容
     */
    public static void saveString(String fileName, String key, String str) {
        SharedPreferences sp = context.getSharedPreferences(fileName, Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = sp.edit();
        editor.putString(key, str);
        editor.commit();
    }

    /**
     * 查看已存的字符串数据
     *
     * @param key
     * @param defaultStr 默认值
     * @return
     */
    public static String getString(String key, String defaultStr) {
        SharedPreferences sp = context.getSharedPreferences(FILE_NAME, Context.MODE_PRIVATE);
        return sp.getString(key, defaultStr);
    }

    /**
     * 查看已存的字符串数据
     *
     * @param key
     * @param defaultStr 默认值
     * @return
     */
    public static String getString(String fileName, String key, String defaultStr) {
        SharedPreferences sp = context.getSharedPreferences(fileName, Context.MODE_PRIVATE);
        return sp.getString(key, defaultStr);
    }

    public static Map<String, String> getAllByFileName(String fileName) {
        SharedPreferences sp = context.getSharedPreferences(fileName, Context.MODE_PRIVATE);
        return (Map<String, String>) sp.getAll();
    }

    /**
     * 移除指定数据
     */
    public static void remove(String key) {
        removeByFileName(FILE_NAME, key);
    }

    /**
     * 移除指定数据
     */
    public static void remove(String fileName, String key) {
        removeByFileName(fileName, key);
    }

    /**
     * 移除指定数据
     */
    public static void removeByFileName(String fileName, String key) {
        SharedPreferences sp = context.getSharedPreferences(fileName,
                Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = sp.edit();
        editor.remove(key);
        editor.commit();
    }

    /**
     * 移除所有数据
     */
    public static void removeAll() {
        removeAllByFileName(FILE_NAME);
    }
    /**
     * 移除所有数据
     */
    public static void removeAll(String fileName) {
        removeAllByFileName(fileName);
    }

    /**
     * 移除所有数据
     */
    public static void removeAllByFileName(String fileName) {
        SharedPreferences sp = context.getSharedPreferences(fileName,
                Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = sp.edit();
        editor.clear().commit();
    }

    /**
     * 将对象进行base64编码后保存到SharePref中
     *
     * @param context
     * @param key
     * @param object
     */
    public static void saveObj(Context context, String key, Object object) {
        SharedPreferences sp = context.getSharedPreferences(FILE_NAME, Context.MODE_PRIVATE);

        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        ObjectOutputStream oos = null;
        try {
            oos = new ObjectOutputStream(baos);
            oos.writeObject(object);
            // 将对象的转为base64码
            String objBase64 = new String(Base64.encode(baos.toByteArray(),
                    Base64.DEFAULT));

            sp.edit().putString(key, objBase64).commit();
            oos.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }


    /**
     * 将SharePref中经过base64编码的对象读取出来
     *
     * @param context
     * @param key
     * @param
     * @return
     */
    public static Object getObj(Context context, String key) {
        SharedPreferences sp = context.getSharedPreferences(FILE_NAME, Context.MODE_PRIVATE);
        String objBase64 = sp.getString(key, null);
        if (TextUtils.isEmpty(objBase64)) {
            return null;
        }

        // 对Base64格式的字符串进行解码
        byte[] base64Bytes = Base64.decode(objBase64.getBytes(), Base64.DEFAULT);
        ByteArrayInputStream bais = new ByteArrayInputStream(base64Bytes);

        ObjectInputStream ois;
        Object obj = null;
        try {
            ois = new ObjectInputStream(bais);
            obj = (Object) ois.readObject();
            ois.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return obj;
    }
}
